; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s
;  Note that if you modify the button remapping scheme here, this character will
; still be able to correctly detect the basic commands of other characters
; complying with the basic command order specified below, as long as their
; buttons haven't been remapped.  But no character (not even one with the same
; remapping scheme, not even another instance of this character) will be able to
; correctly detect this character's commands.  This shouldn't ever result in any
; false positives, but it could delay correct positives, and could erroneously
; make the helper AI activation method trigger a false negative in team simul
; modes, in which case the XOR-ed commands method would be needed to provide
; backup.  But of course, this isn't an issue in any version of Mugen prior to
; version 2002.04.14.

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


; These 11 Single Button and Hold Dir commands must be placed here at the top
; of the CMD, above all other commands, and in the standard order shown here,
; in order for the "Compatibly Partnered" version (9742) of the helper AI
; activation method to work with different partners in simul team mode.
; (When the partner is not compatible, then it's best to just use the regular
; version (9741) and rely on the XOR method for backup in case a human
; partner's input turns off the CPU partner's AI.)
;   (Now, even if you do not intend to give your character any custom AI, it
; would still be nice if you would place the commands at the top of your CMD,
; for the sake of other characters which do use this AI activation method.
; And then, define Anim 9741 in your AIR file to indicate to other characters
; that your character is compatible.
;   It may slightly increase the chances of faulty AI activation if the user
; is using characters with a poor implementation of the old humanly-impossible
; commands AI activation method when fighting against your character, but
; other than that, there's really no particular reason not to.  And you can
; change the names of the commands if you want.  For compatibility, all that
; really matters is the "command" and "time" parameters.)
;
; Please don't add any extra definitions for any of these 11 basic command
; names, nor for any of the 7 "hold[button]" command names that follow.
; For example, things like this should be avoided:
;	[Command]
;	name = "z"
;	command = y+b
;	time = 1
; There are several workarounds possible to achieve the same effect.  Please
; feel free to ask me about it if you have any uncertainty.
; Violating this rule would cause the KeyCtrl Helper method and/or the XORed
; Commands method to malfunction, and could also interfere with other future
; applications of this command order standard.
;
;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;--- None of your own command definitions should be above this line. ---

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

;[Command]
;name = "recovery2"
;command = x+y
;time = 1

; Here add matching commands for any moves that must never be used randomly
; by the computer, such as suicide moves and super moves, and add the pairs
; to the XOR VarSet controller in State -3.

; If you're desperate to make sure that the AI always gets turned on as soon
; as possible, you can add more equivalents for your own commands here too,
; and add to the XOR VarSet controller's triggers accordingly.

; And of course, if you've run out of unique command labels (Mugen allows
; 128), you can remove as many of these as you want.  You'll of course need
; to modify the XOR VarSet controller's triggers accordingly, but Mugen
; will let you know if you forget to do so. :)


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "FatalKO"
command = ~D, DB, B, D, DB, B, x+y
time = 22
buffer.time = 40
[Command]
name = "FatalKO"
command = ~D, B, D, B, x+y
time = 22
buffer.time = 40
[Command]
name = "RisingDragon"
command = ~F, D, DF, x+y
[Command]
name = "RisingDragon"
command = ~F, D, F, x+y
[Command]
name = "RisingDragon"
command = ~D, DF, F, x+y
[Command]
name = "RisingDragon"
command = ~D, F, x+y
[Command]
name = "SuperKick"
command = ~D, DB, B, a+b
[Command]
name = "SuperKick"
command = ~D, B, a+b
[Command]
name = "SuperPunch"
command = ~D, DB, B, x+y
[Command]
name = "SuperPunch"
command = ~D, B, x+y
[Command]
name = "BBBreak"
command = ~D, DF, F, a+b
[Command]
name = "BBBreak"
command = ~D, F, a+b
[Command]
name = "IGonnaGitYa"
command = ~B,DB,D,DF,F, a+b
[Command]
name = "IGonnaGitYa"
command = ~B,D,F, a+b

;-| Special Motions |------------------------------------------------------
[Command]
name = "SuckerPunch"
command = ~D, DB, B, x
[Command]
name = "SuckerPunch"
command = ~D, DB, B, y
[Command]
name = "Hadouken"
command = ~D, DF, F, x
[Command]
name = "Hadouken"
command = ~D, DF, F, y
[Command]
name = "Shoryuken"
command = ~F, D, DF, x
[Command]
name = "Shoryuken"
command = ~F, D, DF, y
[Command]
name = "Shoryuken"
command = ~F, D, DF, a
[Command]
name = "Shoryuken"
command = ~F, D, DF, x
[Command]
name = "Shoryuken"
command = ~F, D, DF, y
[Command]
name = "FalconDive"
command = ~F, D, DF, a
[Command]
name = "FalconDive"
command = ~F, D, DF, b
[Command]
name = "AirKick"
command = ~D, DB, B, a
[Command]
name = "AirKick"
command = ~D, DB, B, b
[Command]
name = "JustRunIntoIT"
command = ~B,DB,D,DF,F, a
[Command]
name = "JustRunIntoIT"
command = ~B,DB,D,DF,F, b
[Command]
name = "SuckerPunch"
command = ~D, B, x
[Command]
name = "SuckerPunch"
command = ~D, B, y
[Command]
name = "Shoryuken"
command = ~F, D, F, x
[Command]
name = "Shoryuken"
command = ~F, D, F, y
[Command]
name = "Shoryuken"
command = ~F, D, F, a
[Command]
name = "FalconDive"
command = ~F, D, F, a
[Command]
name = "FalconDive"
command = ~F, D, F, b
[Command]
name = "AirKick"
command = ~D, B, a
[Command]
name = "AirKick"
command = ~D, B, b
[Command]
name = "JustRunIntoIT"
command = ~B,D,F, a
[Command]
name = "JustRunIntoIT"
command = ~B,D,F, b
[Command]
name = "SecretMove"
command = ~F,B,D,F,x+y
[Command]
name = "SecretMove"
command = ~F,B,DB,D,DF,F,x+y
[Command]
name = "MashyMashy"
command = x,x,x
time = 23
[Command]
name = "MashyMashy"
command = y,y,y
time = 23


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "AFF"     ;Required (do not remove)
command = $F, ~F, F
time = 10

[Command]
name = "ABB"     ;Required (do not remove)
command = $B, ~B, B
time = 10

[Command]
name = "SupahJump"
;command = ~$D, $U
command = ~$D, $U
time = 5
buffer.time = 2

[Command]
name = "ChargedSupahJump"
;command = ~$D, $U
command = ~12$D, $U
time = 5
buffer.time = 2

[Command]
name = "upper_what"
command = ~15$D, $U, x
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, y
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, z
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, a
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, b
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, c
time = 10


[Command]
name = "PICK"     ;Required (do not remove)
command = U
[Command]
name = "PICK"     ;Required (do not remove)
command = D
;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = a, a
time = 10

[Command]
name = "recovery"
command = b, b
time = 10

[Command]
name = "recovery"
command = x, x
time = 10

[Command]
name = "recovery"
command = y, y
time = 10


;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; nor encounters any VarSets within State -1.
; But they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

; This is generally the best place to put most of your AI directives.  For
; example, this controller would only be executed when the CPU is in control:
;
; [State -1, Haha!]
; type = ChangeState
; trigger1 = var(0) ; (Or use "var(58)>0" if you've chosen not to
;                   ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = StateType = S
; trigger1 = MoveType = I
; trigger1 = P2MoveType = H
; trigger1 = NumEnemy = 1
; trigger1 = Enemy,GetHitVar(HitTime) > 60
; trigger1 = PrevStateNo != 195
; trigger1 = Random < 99
; value = 195

; And of course, most human-only command-based ChangeStates also belong
; in State -1.  For example, this move would only be performable by a human:
;
; [State -1, Death Before Dishonor]
; type = ChangeState
; trigger1 = command = "suicide"
; trigger1 = !var(0) ; (Or use "var(58)<1" if you've chosen not to
;                    ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = StateType != A
; trigger1 = MoveType = I
; value = {suicide state number}


;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact
trigger3 = stateno = 3200
trigger4 = stateno = 720
trigger4 = movecontact
var(1) = 1

; AI GOES HERE

[State -1, AI Consideration reset]
type = VarSet
trigger1 = 1
var(52) = 0
ignorehitpause = 1

[State AI, Consider backing off]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 80
triggerall = random < 200
triggerall = numenemy
triggerall = (p2stateno = [5110,5130]) || ((enemynear,time <= 10) && (enemynear,prevstateno = 5120)) || (p2dist x <= -10)
triggerall = p2bodydist x <= 33
triggerall = backedgedist >= 33 || p2dist x <= -5
triggerall = time >= 6-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = ctrl
trigger2 = stateno = 1400
var(52) = 105

[State AI, Consider S.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + ((50*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),50-(6*(movecontact>=1))]
triggerall = p2dist y >= -60 - (enemynear,vel y*2)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -65
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 3200
trigger2 = stateno = 720
trigger2 = movecontact
var(52) = 200
ignorehitpause = 1
[State AI, Consider S.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + ((50*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),ifelse(!var(59),46,34)-(6*(movecontact>=1))]
triggerall = p2dist y >= -80 - (enemynear,vel y*2)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -90
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400
trigger2 = (animtime >= -6) || movecontact
trigger3 = (var(59) = 1) && ((stateno = 430 || stateno = 440 || stateno = 210 || stateno = 410) && (prevstateno != 200 && prevstateno != 400 && prevstateno != 410))
trigger3 = (animtime >= -6) || movecontact
var(52) = 230
ignorehitpause = 1
[State AI, Consider S.Y]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + ((50*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),85-(6*(movecontact>=1))]
triggerall = p2dist y >= -33 - (enemynear,vel y*8)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = (var(59) = 0) && (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430)
trigger2 = (animtime >= -6) || movecontact
trigger3 = (var(59) = 1) && (stateno = 200 || stateno = 400 || stateno = 430)
trigger3 = (animtime >= -6) || movecontact
var(52) = 210
ignorehitpause = 1
[State AI, Consider S.B]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + ((50*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),50-(6*(movecontact>=1))]
triggerall = p2dist y >= -62 - (enemynear,vel y*12)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = var(59) = 0
trigger2 = stateno = 230
trigger2 = (animtime >= -6) || movecontact
trigger3 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 430 || stateno = 440)
trigger3 = (var(59) = 0) || (prevstateno != 200 && prevstateno != 400 && prevstateno != 430 && prevstateno != 210)
trigger3 = (animtime >= -6) || movecontact
var(52) = 240
ignorehitpause = 1

[State AI, Consider C.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + ((50*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),45-(6*(movecontact>=1))]
triggerall = p2dist y >= -20 - (enemynear,vel y*2)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -38
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 3200
trigger2 = (var(59) = 0) && (stateno = 200)
trigger2 = (animtime >= -6) || movecontact
var(52) = 400
ignorehitpause = 1
[State AI, Consider C.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + ((50*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),51-(6*(movecontact>=1))]
triggerall = p2dist y >= -8 - (enemynear,vel y*2)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = (var(59) = 0) && (stateno = 400 || stateno = 200)
trigger2 = (animtime >= -6) || movecontact
var(52) = 430
ignorehitpause = 1
[State AI, Consider C.Y]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + ((50*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,12),51-(6*(movecontact>=1))]
triggerall = p2dist y >= -75 - (enemynear,vel y*2)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = var(59) = 0
trigger2 = stateno = 230
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 400 || stateno = 430 || stateno = 200 || stateno = 210 || stateno = 440
trigger3 = (var(59)=0) || (prevstateno != 400 && prevstateno != 430 && prevstateno != 200 && prevstateno != 210 && prevstateno != 440)
trigger3 = (animtime >= -6) || movecontact
var(52) = 410
ignorehitpause = 1
[State AI, Consider C.B]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + ((50*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),51-(6*(movecontact>=1))]
triggerall = p2dist y >= -8 - (enemynear,vel y*2)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = (var(59) = 0) && (stateno = 400 || stateno = 430 || stateno = 200 || stateno = 230 || stateno = 210)
trigger2 = (animtime >= -6) || movecontact
var(52) = 440
ignorehitpause = 1

[State AI, Consider F.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + ((50*var(55))*(movehit)) + (100*(p2statetype = C))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,20),105-(6*(movecontact>=1))]
triggerall = p2dist y >= -60 - (enemynear,vel y*2)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = fvar(38) >= 4
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = stateno = 210 || stateno = 410 || stateno = 240 || (stateno = 230 && anim = 232)
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 200 || stateno = 400 || stateno = 230 || stateno = 430
trigger3 = moveguarded && p2statetype = C
var(52) = 205
ignorehitpause = 1
[State AI, Consider F.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + ((50*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = (p2stateno != [5080,5130]) || fvar(38) >= 4
triggerall = p2stateno != 5120
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,40),87+(10*(fvar(38)>=4))-(6*(movecontact>=1))]
triggerall = p2dist y >= -50 - (enemynear,vel y*8)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -28
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno != 235
trigger1 = stateno != 205
var(52) = 235
ignorehitpause = 1
[State AI, Consider TWERPTWERPTWERPTWERP]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = var(55)
triggerall = random < (66*var(55)) + ((50*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),80-(6*(movecontact>=1))]
triggerall = p2dist y >= -60 - (enemynear,vel y*2)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 230 || stateno = 210 || stateno = 400 || stateno = 430 || stateno = 410 || stateno = 240 || stateno = 440
trigger2 = (animtime >= -6) || movecontact
var(52) = 1700
ignorehitpause = 1
[State AI, Consider Breaking off guard]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,640]) )
triggerall = var(55)
triggerall = random < (10*var(55))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
triggerall = p2movetype != H || (p2stateno=[120,169])
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),60]
triggerall = p2dist y >= -40 - (enemynear,vel y*8)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -50
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
var(52) = 720
ignorehitpause = 1

[State -1, J.A]
type = Varset
triggerall = var(52) = 0 || random < 123
triggerall = var(55)
triggerall = p2bodydist x = [-15,49]
triggerall = P2dist y = [-5+(vel y*3),70+(vel y*3)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0
triggerall = p2movetype != A || (stateno != [120,169])
triggerall = random < (23*var(55))
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
var(52) = 630
[State -1, J.X]
type = Varset
triggerall = var(52) = 0 || random < 93
triggerall = var(55)
triggerall = (p2bodydist x = [-15,40]) || (movehit)
triggerall = P2dist y = [-80+(vel y*6),35+(vel y*6)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A
triggerall = p2movetype != A || (stateno != [120,169])
triggerall = random < (23*var(55))
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
trigger2 = (stateno = 600)
trigger2 = movecontact
var(52) = 600
[State -1, J.B]
type = Varset
triggerall = var(52) = 0 || random < 93
triggerall = var(55)
triggerall = (p2bodydist x = [-15,40]) || (movehit)
triggerall = P2dist y = [-70+(vel y*6),80+(vel y*6)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0
triggerall = p2movetype != A || (stateno != [120,169])
triggerall = random < (23*var(55))
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
trigger2 = (stateno = 600) || (stateno = 630)
trigger2 = movecontact
var(52) = 640
[State -1, J.Y]
type = Varset
triggerall = var(52) = 0 || random < 93
triggerall = var(55)
triggerall = (p2bodydist x = [-15,40]) || (movehit)
triggerall = P2dist y = [-50+(vel y*6),90+(vel y*6)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0
triggerall = p2movetype != A || (stateno != [120,169])
triggerall = random < (23*var(55))
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
trigger2 = (stateno = 600) || (stateno = 630) || (stateno = 640 && !var(59))
trigger2 = movecontact
var(52) = 610


[State AI, Consider Otoko Punching]
type = VarSet
triggerall = numenemy
triggerall = stateno != 235 || animelemtime(14) > 0
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,640]) )
triggerall = var(55)
triggerall = random < (44*var(55)) + ((20*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,4),129-(6*(movecontact>=1))]
triggerall = (p2dist y >= -60 - (enemynear,vel y*2)) || (stateno = [1100,1110])
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = !var(59)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(1)
trigger2 = stateno = [1100,1105]
trigger2 = movehit
trigger3 = stateno = 1400 || stateno = 3200
trigger3 = anim != 210
trigger3 = time >= 6
var(52) = 1000+ifelse(random<500&&(stateno!=[1100,1110]),10,0)
ignorehitpause = 1
[State AI, Consider Heita Kicking]
type = VarSet
triggerall = numenemy
triggerall = stateno != 235 || animelemtime(14) > 0
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,640]) )
triggerall = var(55)
triggerall = random < (44*var(55)) + ((20*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,ifelse(var(59),-5,45),0),111-(6*(movecontact>=1))]
triggerall = p2dist y >= ifelse(!var(59),-78,-10) - (enemynear,vel y*9)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(1)
trigger2 = stateno = [1100,1105]
trigger2 = movehit
trigger3 = stateno = 1400 || stateno = 3200
trigger3 = anim != 210
trigger3 = time >= 6
var(52) = 1200+ifelse(random<500&&(stateno!=[1100,1110]),10,0)
ignorehitpause = 1
[State AI, Consider Shooting]
type = VarSet
triggerall = numenemy
triggerall = stateno != 235 || animelemtime(14) > 0
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,640]) )
triggerall = var(55)
triggerall = random < (18*var(55))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || (EnemyNear, animtime >= -3)
triggerall = p2stateno != [5080,5130]
triggerall = (p2bodydist x = [ifelse(p2statetype!=A,20,70),183-(6*(movecontact>=1))]) || (!var(59))
triggerall = p2bodydist x >= 70 || var(59)
triggerall = p2dist y >= -60 - (enemynear,vel y*2)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(1)
trigger2 = stateno = [1100,1105]
trigger2 = movehit
var(52) = 1600+ifelse((p2bodydist x>=110&&var(59)=0)||random<500,1610,0)
ignorehitpause = 1
[State AI, Consider That Anti-air]
type = Varset
triggerall = var(52) = 0 || random < 153
triggerall = var(55)
triggerall = stateno != 235 || animelemtime(14) > 0
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),28-(6*(movecontact>=1))+(9*(stateno>=1400))]
triggerall = P2dist y = [-180,10]
;triggerall = Statetype != A
triggerall = random < (20*var(55)) + ((15*var(55))*(movehit)) + (100*(p2statetype=A)) + ((lifemax - life)/4) || (stateno = 52 && random < 650)
triggerall = p2stateno != [5080,5120]
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -30
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 550)
triggerall = time >= 7-var(55) || random < 10
trigger1 = var(1) || (stateno = [600,640])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 120 || p2movetype = H
trigger2 = stateno = 1400 || stateno = 3200
trigger2 = anim != 210
trigger2 = time >= 6
trigger3 = fvar(38) >= 4
trigger3 = stateno = 1100 || stateno = [1200,1210]
var(52) = ifelse(p2bodydist x>=25,1105,1100+((random%3)*5))
[State AI, Consider running agressively]
type = VarSet
triggerall = numenemy
triggerall = stateno != 235 || animelemtime(14) > 0
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,640]) )
triggerall = var(55)
triggerall = p2bodydist x >= 50 || stateno = 1001
triggerall = p2stateno != [5080,5130]
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = !var(59)
trigger1 = stateno != 1400
trigger1 = stateno != 3200
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(1)
trigger1 = random < (9*var(55))*ifelse(movecontact,2,1)
trigger2 = stateno = 1001
trigger2 = movecontact >= 6
trigger2 = random <= 100*var(55)
var(52) = ifelse(power>=1000&&random<50&&stateno!=1001,3200,1400)
ignorehitpause = 1
[State AI, Consider Falcon Punching]
type = VarSet
triggerall = numenemy
triggerall = stateno != 235 || animelemtime(14) > 0
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,640]) )
triggerall = var(55)
triggerall = random < (44*var(55)) + ((20*var(55))*(movehit))
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,4),129-(6*(movecontact>=1))]
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x >= 120 || p2movetype = H
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(59)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger1 = !movehit || p2statetype = A
trigger2 = (stateno = 235) && (prevstateno = 410)
trigger2 = animelemtime(13) > 0
trigger2 = movehit
var(52) = 1000
ignorehitpause = 1

[State AI, Consider Dialk]
type = Varset
triggerall = p2stateno != [5100,5120]
triggerall = numenemy
triggerall = var(52) = 0 || random < 150
triggerall = var(55)
triggerall = random < (44*var(55)) + ((20*var(55))*(movehit))
triggerall = p2dist y > -40
triggerall = (p2bodydist x - p2bodydist y - (enemynear,vel y*12)) = [-40,50]
triggerall = p2bodydist x <= 72
;triggerall = p2bodydist x = [-19+(p2bodydist y)+(enemynear,vel x),1+(p2bodydist y)+(enemynear,vel x)]
;triggerall = p2bodydist y = [(p2bodydist x)-25,(p2bodydist x)+25]
triggerall = statetype = A
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
trigger2 = random < (stateno/2)
trigger2 = (stateno = [600,655]) || ((stateno = [1200,1210]) && fvar(38) >= 4)
trigger2 = movehit
var(52) = 1300+((random%2)*10)

[State AI, Consider Dialk]
type = Varset
triggerall = p2stateno != [5100,5120]
triggerall = numenemy
triggerall = var(52) = 0 || random < 150
triggerall = var(55)
triggerall = random < (44*var(55)) + ((20*var(55))*(movehit))
triggerall = p2bodydist y = [-5,90]
triggerall = p2bodydist x = [-15,45]
triggerall = var(59) = 1
triggerall = statetype = A
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl
trigger2 = stateno = 640 || (stateno = 230 && anim = 232)
trigger2 = movecontact
var(52) = 1350+((random%2)*10)

[State AI, Consider a shooter]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || (random < 100 && (var(52)!=[200,640]))
triggerall = var(55)
triggerall = stateno != 235 || animelemtime(14) > 0
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0 && enemynear, animtime <= -10)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(statetype!=A,-5,20),180]
triggerall = p2dist y + (enemynear,vel y*6) = [-60,0]
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -30
triggerall = statetype != A
triggerall = power >= 1000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
triggerall = p2stateno != [120,165]
triggerall = prevstateno != [3000,3902]
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*11) + (enemynear, pos y) <= -11 ) || (p2stateno != [5030,5120])
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl || (stateno = 52)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = random < (stateno/2)
trigger2 = (stateno = [200,499]) || (stateno = [1001,1120])
trigger2 = movehit
var(52) = ifelse(random<500&&fvar(38)>=4,3200,3000)
ignorehitpause = 1
[State AI, Consider a manly uppercut]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 200
triggerall = var(55)
triggerall = stateno != 235 || animelemtime(14) > 0
triggerall = random < 300 + ((lifemax - life)/16) || (stateno = 52 && random < 650)
;triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0 && enemynear, animtime <= -9)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,23+ifelse(fvar(38)>=4,4,0)-(6*(movecontact>=1))]
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -30
triggerall = power >= 1000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
triggerall = p2stateno != [120,165]
triggerall = prevstateno != [3000,3902]
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*8) + (enemynear, pos y) <= -8 ) || (p2stateno != [5030,5120])
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl || (stateno = 52)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = random < (stateno/2)
trigger2 = (stateno = [200,499]) || (stateno = 1001 || stateno = 1200 || stateno = 1210 || stateno = 1010)
trigger2 = movehit
var(52) = 3100
ignorehitpause = 1
[State AI, Consider following up]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 200
triggerall = var(55)
triggerall = power >= 2000
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno = 3100
trigger1 = fvar(38) < 4
trigger1 = movehit = [1,8]
var(52) = 3400
ignorehitpause = 1
[State AI, Consider outright destroying the fucker]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < (112*var(55))
triggerall = var(55)
;triggerall = random < 300 + ((lifemax - life)/16)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-90,90]
triggerall = p2dist y + (enemynear,vel y*6) = [-60,0]
triggerall = statetype != A
triggerall = power >= 5000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A)
triggerall = p2stateno != [120,165]
triggerall = prevstateno != [3000,3902]
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*9) + (enemynear, pos y) <= -5 ) || (p2stateno != [5030,5120])
triggerall = fvar(38) >= 4
triggerall = time >= 7-var(55) || random < 10
triggerall = p2life <= 900
trigger1 = ctrl || (stateno = 52)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = random < (stateno/2)
trigger2 = (stateno = [200,499]) || (stateno = [1000,1120])
trigger2 = movehit
var(52) = 3500
ignorehitpause = 1

[State AI, Consider Throwing]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 900
triggerall = var(55)
triggerall = random < (111*var(55))
triggerall = p2stateno != [5080,5130]
triggerall = abs(p2bodydist x) < 10
triggerall = statetype != A
triggerall = p2movetype != H
triggerall = p2statetype != A
triggerall = prevstateno != [800,860]
trigger1 = stateno != 40
trigger1 = ctrl
var(52) = 800
ignorehitpause = 1

[State AI, Consider Countering/Guard Canceling]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 55+var(55)
triggerall = var(55)
triggerall = random < (2*var(55)) + ifelse(p2life - life<0,0,(p2life - life)/4)
triggerall = p2bodydist x = [-5,60]
triggerall = p2dist y >= -50
triggerall = statetype != A
triggerall = power >= 500
triggerall = power < 2500 || random < 150 || power >= 3500
triggerall = time >= 5-var(55) || random < 10
trigger1 = stateno = 150 || stateno = 152
var(52) = 700
ignorehitpause = 1

[State AI, Consider Advancing]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = random < (33*var(55))
triggerall = ((enemynear, ctrl = 0) && p2movetype != A) || (p2movetype = A && (enemynear, facing = facing))
triggerall = (p2stateno != [5080,5130]) || (p2bodydist x = [45,100])
triggerall = p2bodydist x >= 45
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno != 40
trigger1 = var(1)
trigger1 = !moveguarded
var(52) = ifelse(random<444&&(p2stateno != [5080,5130]),1400,100)

[State AI, Consider Taunting]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 10+var(55)
triggerall = var(55)
triggerall = fvar(38) <= 4
triggerall = p2stateno != 5120
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
triggerall = (p2movetype = H && (p2statetype != S && p2statetype != C))
triggerall = statetype != A
triggerall = prevstateno != 195
triggerall = random < 66 + (200*(anim=5300))
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100 || (p2movetype = H && p2statetype = A)
trigger1 = var(1)
trigger2 = statetype != A
trigger2 = stateno = 1001 || stateno = 1100 || stateno = 1110 || stateno = 1120
trigger2 = movehit
var(52) = 720
ignorehitpause = 1


[State -1, AIR CHOMBO]
type = Varset
var(52) = 40
triggerall = var(55)
triggerall = Statetype != A
trigger1 = stateno = 410 || (stateno = [1120,1125])
trigger1 = movehit

[State AI, Guard S]
type = ChangeState
triggerall = stateno != 40
triggerall = !numhelper(998)
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = time >= 7-var(55) || random < 10
trigger1 = (P2StateType != C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<88&&(stateno!=[120,169]),ifelse(p2bodydist x<=20&&random<500,1100,ifelse(var(59)=0&&random<150,1400,40)),130)

[State AI, Guard L]
type = ChangeState
triggerall = stateno != 40
triggerall = !numhelper(998)
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = time >= 7-var(55) || random < 10
trigger1 = (P2StateType = C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<88&&(stateno!=[120,169]),ifelse(p2bodydist x<=20&&random<500,1100,ifelse(var(59)=0&&random<150,1400,40)),131)


; AI ENDS HERE

;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar)
;OJt[˂iQ[WxPj
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3500
triggerall = (!var(55) && command = "FatalKO") || var(52) = 3500
triggerall = power >= 5000
triggerall = fvar(38) >= 4
triggerall = !var(55)
trigger1 = var(1)
trigger2 = stateno = 1400 || stateno = 3200
trigger2 = anim != 210
trigger3 = statetype != A
trigger3 = stateno = [1000,1399]
trigger3 = movecontact
trigger4 = (stateno = 3301) || (stateno = 1700 && (anim = 1701 || movecontact))
trigger5 = stateno = 52 && time

[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = (!var(55) && command = "SuperKick") || var(52) = 3000
triggerall = power >= ifelse((stateno=[3000,3699]),2000,1000)
trigger1 = var(1)
trigger2 = stateno = 1400 || stateno = 3200
trigger2 = anim != 210
trigger3 = statetype != A
trigger3 = stateno = [1000,1399]
trigger3 = movecontact
trigger4 = (stateno = 3301) || (stateno = 1700 && (anim = 1701 || movecontact))
trigger5 = stateno = 52 && time

[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3200
triggerall = (!var(55) && command = "IGonnaGitYa") || var(52) = 3200
triggerall = power >= ifelse((stateno=[3000,3699]),2000,1000)
trigger1 = var(1)
trigger2 = stateno = 1400 || stateno = 3200
trigger2 = anim != 210
trigger3 = statetype != A
trigger3 = stateno = [1000,1399]
trigger3 = movecontact
trigger4 = stateno = 52 && time
trigger5 = (stateno = 1700 && (anim = 1701 || movecontact))

[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3300
triggerall = (!var(55) && command = "SuperPunch") || var(52) = 3300
triggerall = power >= ifelse((stateno=[3000,3699]),2000,1000)
triggerall = fvar(38) >= 4
trigger1 = var(1)
trigger2 = stateno = 1400 || stateno = 3200
trigger2 = anim != 210
trigger3 = statetype != A
trigger3 = stateno = [1000,1399]
trigger3 = movecontact
trigger4 = stateno = 52 && time
trigger5 = (stateno = 1700 && (anim = 1701 || movecontact))

[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3400
triggerall = (!var(55) && command = "BBBreak") || var(52) = 3400
triggerall = power >= 2000
triggerall = fvar(38) < 4
trigger1 = stateno = 3100
trigger1 = time >= 11

[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3100
triggerall = (!var(55) && command = "RisingDragon") || var(52) = 3100
triggerall = power >= ifelse((stateno=[3000,3699]),2000,1000)
trigger1 = var(1)
trigger2 = stateno = 1400 || stateno = 3200
trigger2 = anim != 210
trigger3 = statetype = A
trigger3 = ctrl
trigger4 = stateno = [600,640]
trigger4 = movecontact
trigger5 = stateno = [1000,1399]
trigger5 = movecontact
trigger6 = (stateno = 3301) || (stateno = 1700 && (anim = 1701 || movecontact))
trigger7 = stateno = 52 && time

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Shoryuken]
type = ChangeState
value = ifelse(var(59)=0,ifelse(command="a"||var(52)=1105,1105,ifelse(command="y"||var(52)=1110,1110,1100)) , 1500 )
triggerall = (!var(55) && command = "Shoryuken") || (var(52) = [1100,1110])
triggerall = command != "a" || var(59) = 0
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1400 || stateno = 3200 || (stateno = 1700 && movecontact) || ((stateno = [1120,1125]) && movecontact)
trigger2 = anim != 210
trigger3 = (stateno = [600,640])
trigger3 = movecontact
trigger4 = var(59) = 0
trigger4 = (stateno = [1200,1210])
trigger4 = fvar(38) >= 4
trigger4 = movecontact
trigger5 = statetype = A
trigger5 = ctrl
trigger6 = stateno = 230
trigger6 = statetype = A
trigger6 = movecontact
trigger7 = fvar(38) >= 4
trigger7 = (stateno = 1100 && (command != "x" && var(52) != 1100))
trigger7 = time >= 9

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Followup]
type = ChangeState
triggerall = command = "holdy"
trigger1 = stateno = 1110
;trigger1 = statetype = A
trigger1 = movehit = [1,8]
value = 1111
;ignorehitpause = 1

;[State -1, Falcon Dive]
;type = ChangeState
;value = 1500
;triggerall = command = "FalconDive"
;triggerall = var(59) = 1
;trigger1 = var(1) ;Use combo condition (above)
;trigger2 = stateno = 1400 || stateno = 3200
;trigger3 = (stateno = [600,640])
;trigger3 = movecontact
;trigger4 = statetype = A
;trigger4 = ctrl
;trigger5 = stateno = 230
;trigger5 = statetype = A
;trigger5 = movecontact


;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Hadouken]
type = ChangeState
value = ifelse(var(59)=1,ifelse(command="y"||var(52)=1610,1125,1120), ifelse(command="y"||var(52)=1610,1610,1600) )
triggerall = (command = "Hadouken") || (var(52) = [1600,1610])
triggerall = var(59) = 1 || !numhelper(1605)
trigger1 = var(1) ;Use combo condition (above)
trigger2 = var(59) = 0
trigger2 = stateno = 1100 || stateno = 1105 || stateno = 1110
trigger2 = statetype != A
trigger2 = movecontact
trigger3 = stateno = 1400 || stateno = 3200 || (stateno = 1700 && movecontact)
trigger3 = anim != 210

[State -1, Knuckle/Falcon Punch]
type = ChangeState
value = ifelse(var(59)=1,1020, ifelse((command="y"||var(52)=1010)&&(fvar(38)>=4),1010,1000) )
triggerall = (command = "SuckerPunch") || (var(52) = [1000,1010])
trigger1 = var(1) ;Use combo condition (above)
trigger2 = var(59) = 0
trigger2 = stateno = 1100 || stateno = 1105 || stateno = 1110
trigger2 = statetype != A
trigger2 = movecontact
trigger3 = stateno = 1400 || stateno = 3200 || (stateno = 1700 && movecontact)
trigger3 = anim != 210

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Heita/Falcon Kick]
type = ChangeState
value = ifelse( var(59)=1, ifelse(command="b",1220,1221) , ifelse((command="b"||var(52)=1210)&&(fvar(38)>=4),1210,1200) )
triggerall = (command = "AirKick") || (var(52) = [1200,1210])
trigger1 = var(1) ;Use combo condition (above)
trigger2 = stateno = 1400 || stateno = 3200 || (stateno = 1700 && movecontact)
trigger2 = anim != 210
trigger3 = var(59) = 0
trigger3 = stateno = 1100 || stateno = 1105 || stateno = 1110
trigger3 = fvar(38) < 4
trigger3 = statetype != A
trigger3 = movecontact

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Aerial Special Kick]
type = ChangeState
value = ifelse((command="b"||var(52)=1310)&&(fvar(38)>=4),1310,1300)
triggerall = (command = "AirKick") || (var(52) = [1300,1310])
trigger1 = ctrl
trigger1 = statetype = A
trigger2 = (stateno = [600,640])
trigger2 = movecontact
trigger3 = var(59) = 0
trigger3 = (stateno = [1200,1210])
trigger3 = (fvar(38)>=4)
trigger3 = movecontact
trigger4 = stateno = 230 && anim = 232
trigger4 = movecontact

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Aerial Special Punch]
type = ChangeState
value = ifelse((command="y"||var(52)=1360),1360,1350)
triggerall = (command = "Hadouken") || (var(52) = [1350,1360])
triggerall = var(59) = 1
trigger1 = ctrl
trigger1 = statetype = A
trigger2 = (stateno = [600,640])
trigger2 = movecontact
trigger3 = stateno = 230 && anim = 232
trigger3 = movecontact


;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Guts Run]
type = ChangeState
value = 1400
triggerall = (command = "JustRunIntoIT") || var(52) = 1400
triggerall = var(59) = 0
trigger1 = ctrl
trigger1 = statetype != A
trigger2 = var(1)
trigger2 = stateno != 235
trigger3 = stateno = 3200
trigger4 = stateno = 1001
trigger4 = movecontact

;---------------------------------------------------------------------------
[State -1, Rapid Punch]
type = ChangeState
value = 1700
triggerall = (command = "MashyMashy") || var(52) = 1700
triggerall = var(59) = 1
trigger1 = ctrl
trigger1 = statetype != A
trigger2 = var(1)
trigger2 = stateno != 235
trigger3 = stateno = 3200

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Standing Double Kick]
type = ChangeState
value = 235
triggerall = (!var(55) && (command = "a" && command = "holdfwd" && command != "holddown")) || var(52) = 235
trigger1 = var(1) ;Use combo condition (above)
trigger1 = stateno != 235
trigger1 = stateno != 205
trigger2 = stateno = 1400 || stateno = 3200
trigger2 = anim != 210

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = (command = "FF") || (var(52) = 100)
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = (command = "BB") || (var(52) = 105)
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 1400 || stateno = 3200

[State -1, Run Fwd]
type = ChangeState
value = 110
triggerall = stateno != 100 || stateno != 105 || stateno != 106
triggerall = var(27) = 0
triggerall = stateno != [110,115]
trigger1 = (command = "AFF") || (var(52) = 100)
trigger1 = statetype = A
trigger1 = pos y <= -15
trigger1 = ctrl

[State -1, Run Bck]
type = ChangeState
value = 115
triggerall = stateno != 100 || stateno != 105 || stateno != 106
triggerall = var(27) = 0
triggerall = stateno != [110,115]
trigger1 = (command = "ABB") || (var(52) = 105)
trigger1 = statetype = A
trigger1 = pos y <= -15
trigger1 = ctrl


[State -1, Lulz, launcher]
type = ChangeState
value = 40
triggerall = (command = "holdup") || (var(52) = [40,43])
trigger1 = stateno = 410 || stateno = 1120 || stateno = 1125 || (stateno = 235 && animelemtime(14) >= 0)
trigger1 = movecontact

;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = var(8) <= 0
triggerall = (command = "b") || var(52) = 800
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
triggerall = !numhelper(998)
trigger1 = command = "holdfwd" || command = "holdback"
trigger1 = p2bodydist X < 5
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H


;---------------------------------------------------------------------------
[State -1, Charge]
type = ChangeState
value = 710
triggerall = command = "holdy" && command = "holdb"
triggerall = (var(55) < 5)
triggerall = power < powermax || fvar(38) >= 4
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
[State -1, Alpha Counter]
type = ChangeState
value = 720
triggerall = ((!var(55) || p2movetype != H ) && (command = "x" && command = "y")) || var(52) = 720
triggerall = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
[State -1, Alpha Counter]
type = ChangeState
value = 700
triggerall = (command = "x" && command = "y") || var(52) = 700
triggerall = power >= 500
triggerall = statetype != A
trigger1 = stateno = [120,169]

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Overhead Attack]
type = ChangeState
value = 205
triggerall = (command = "x" && command = "holdfwd" && command != "holddown") || var(52) = 205
triggerall = fvar(38) >= 4
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 230 || stateno = 210 || stateno = 400 || stateno = 430 || stateno = 410 || stateno = 240 || stateno = 440
trigger2 = time > 9 || movecontact
trigger3 = stateno = 3200
trigger4 = stateno = 720
trigger4 = movecontact

;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = (command = "x" && command != "holddown") || var(52) = 200
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 3200
trigger3 = stateno = 720
trigger3 = movecontact

[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = (command = "y" && command != "holddown") || var(52) = 210
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = var(59) = 0
trigger2 = stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 3200
trigger4 = var(59) = 1
trigger4 = stateno = 200 || stateno = 400 || stateno = 430
trigger4 = (animtime >= -6) || movecontact
trigger5 = stateno = 720
trigger5 = movecontact

[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = (command = "a" && command != "holddown") || var(52) = 230
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 3200
trigger4 = var(59) = 1
trigger4 = (stateno = 430 || stateno = 440 || stateno = 210 || stateno = 410) && (prevstateno != 200 && prevstateno != 400 && prevstateno != 410)
trigger4 = (animtime >= -6) || movecontact
trigger5 = stateno = 720
trigger5 = movecontact

[State -1, Stand Strong Kick]
type = ChangeState
value = 240
triggerall = (command = "b" && command != "holddown") || var(52) = 240
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = var(59) = 0
trigger2 = stateno = 230
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 3200
trigger4 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 430 || stateno = 440)
trigger4 = (var(59) = 0) || (prevstateno != 200 && prevstateno != 400 && prevstateno != 430 && prevstateno != 210)
trigger4 = (animtime >= -6) || movecontact
trigger5 = stateno = 720
trigger5 = movecontact


;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = (!var(55) && command = "start") || var(52) = 195
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 1400 || stateno = 3200
trigger3 = var(1)
trigger4 = statetype != A
trigger4 = stateno = 1001 || stateno = 1100 || stateno = 1110 || stateno = 1120
trigger4 = movecontact

[State -1, Switch]
type = ChangeState
value = 730
triggerall = command = "c"
triggerall = power >= 500
triggerall = !var(55) || stateno != 730
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = (command = "x" && command = "holddown") || var(52) = 400
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 3200
trigger3 = var(59) = 0
trigger3 = stateno = 200
trigger3 = (animtime >= -6) || movecontact
trigger4 = stateno = 720
trigger4 = movecontact

[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = (command = "y" && command = "holddown") || var(52) = 410
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = var(59) = 0
trigger2 = stateno = 230
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 3200
trigger4 = stateno = 400 || stateno = 430 || stateno = 200 || stateno = 210 || stateno = 440
trigger4 = (var(59)=0) || (prevstateno != 400 && prevstateno != 430 && prevstateno != 200 && prevstateno != 210 && prevstateno != 440)
trigger4 = (animtime >= -6) || movecontact
trigger5 = stateno = 720
trigger5 = movecontact

[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = (command = "a" && command = "holddown") || var(52) = 430
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = var(59) = 0
trigger2 = stateno = 400 || stateno = 200
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 3200
trigger4 = stateno = 720
trigger4 = movecontact

[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = (command = "b" && command = "holddown") || var(52) = 440
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = var(59) = 0
trigger2 = stateno = 400 || stateno = 430 || stateno = 200 || stateno = 230 || stateno = 210
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 3200
trigger4 = stateno = 720
trigger4 = movecontact


;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = (command = "x") || var(52) = 600
trigger1 = statetype = A
trigger1 = ctrl
;trigger2 = var(59) = 0
trigger2 = stateno = 630
trigger2 = statetime >= 9 || movecontact

[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = (command = "y") || var(52) = 610
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 9 || movecontact
trigger3 = stateno = 630
trigger3 = statetime >= 9 || movecontact
trigger4 = stateno = 640
trigger4 = statetime >= 12 || movecontact
trigger4 = var(59) = 0

[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = (command = "a") || var(52) = 630
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = (command = "b") || var(52) = 640
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 630 || stateno = 600
trigger2 = statetime >= 9 || movecontact

;[State -1, TEST]
;type = ChangeState
;value = 1020
;triggerall = statetype != A
;triggerall = ctrl
;trigger1 = p2stateno = 1020
;trigger2 = command = "z"

